pub struct Input {
pub periodStart: FHIRDate,
pub periodEnd: FHIRDate,
pub topic: FHIRString,
pub subject: FHIRString,
}Fields
periodStart: FHIRDateThe start of the measurement period. In keeping with the semantics of the date parameter used in the FHIR search operation, the period will start at the beginning of the period implied by the supplied timestamp. E.g. a value of 2014 would set the period s
periodEnd: FHIRDateThe end of the measurement period. The period will end at the end of the period implied by the supplied timestamp. E.g. a value of 2014 would set the period end to be 2014-12-31T23:59:59 inclusive
topic: FHIRStringThe topic to be used to determine which measures are considered for the care gaps report. Any measure with the given topic will be included in the report
subject: FHIRStringSubject for which the care gaps report will be produced